==> eiffelstudio-18.01.10.1424.tar: F_code/C1/in31.c <==
/*
 * Code for class INVARIANT_ADAPTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in31.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INVARIANT_ADAPTER}.register */
void F32_615 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_3_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	{
		/* INLINED CODE (record_invariant) */
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_1_) == tr1)) {
			tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_12_);
			F1452_14249(RTCW(tr1), Current);
		} else {
			tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_12_);
			F1452_14250(RTCW(tr1), Current);
		}
		/* END INLINED CODE */
	}
	;
	RTLE;
}

/* {INVARIANT_ADAPTER}.ast */
EIF_REFERENCE F32_616 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {INVARIANT_ADAPTER}.source_class */
EIF_REFERENCE F32_617 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {INVARIANT_ADAPTER}.format */
void F32_618 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	F2420_26749(RTCW(arg1));
	{
		/* INLINED CODE (init_variant_context) */
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F2420_26734(RTCW(arg1), tr1);
		tr2 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_45_);
		RTAR(arg1, tr2);
		*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_12_) = (EIF_REFERENCE) tr2;
		F2420_26810(RTCW(arg1));
		F1084_11655(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (format_ast) */
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_18_);
		F2377_25709(RTCW(tr2), tr1);
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (commit) */
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		F1459_14294(RTCW(tr1));
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		tr1 = F1459_14290(RTCW(tr1));
		RTAR(arg1, tr1);
		*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_14_) = (EIF_REFERENCE) tr1;
		/* END INLINED CODE */
	}
	;
	RTLE;
}

void EIF_Minit31 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C1/in31.c <==
/*
 * Code for class INVARIANT_ADAPTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in31.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INVARIANT_ADAPTER}.register */
void F32_291 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_3_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	{
		/* INLINED CODE (FORMAT_REGISTRATION.record_invariant) */
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_1_) == tr1)) {
			tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_12_);
			F1497_14739(RTCW(tr1), Current);
		} else {
			tr1 = *(EIF_REFERENCE *)(RTCW(arg2) + _REFACS_12_);
			F1497_14740(RTCW(tr1), Current);
		}
		/* END INLINED CODE */
	}
	;
	RTLE;
}

/* {INVARIANT_ADAPTER}.format */
void F32_294 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Current);
	RTLIU(4);
	
	RTGC;
	{
		/* INLINED CODE (TEXT_FORMATTER_DECORATOR.begin) */
		tr1 = (EIF_REFERENCE)  0;
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_14_);
		tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		F1505_14784(RTCW(tr2), tr1);
		RTAR(arg1, tr1);
		*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_14_) = (EIF_REFERENCE) tr1;
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (TEXT_FORMATTER_DECORATOR.init_variant_context) */
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		F2452_27121(RTCW(arg1), tr1);
		tr2 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_45_);
		RTAR(arg1, tr2);
		*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_12_) = (EIF_REFERENCE) tr2;
		F2452_27197(RTCW(arg1));
		F779_11334(RTCW(arg1));
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (TEXT_FORMATTER_DECORATOR.format_ast) */
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_18_);
		F2430_26243(RTCW(tr2), tr1);
		/* END INLINED CODE */
	}
	;
	{
		/* INLINED CODE (TEXT_FORMATTER_DECORATOR.commit) */
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		F1505_14786(RTCW(tr1));
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		tr1 = F1505_14782(RTCW(tr1));
		RTAR(arg1, tr1);
		*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_14_) = (EIF_REFERENCE) tr1;
		/* END INLINED CODE */
	}
	;
	RTLE;
}

void EIF_Minit31 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
